#read in data
mammals <- read.csv('ga-mammals.csv')
covariates <- read.csv('covariates.csv')

# one data set has counties capitalized (e.g. "Clarke") the other doesn't (e.g. "clarke")
# so we write a function to change "clarke" to "Clarke" etc.
firstup <- function(x) {
  substr(x, 1, 1) <- toupper(substr(x, 1, 1))
  x
}

# and apply the function
mammals$county <- as.character(mammals$county)
mammals$county <- sapply(mammals$county,firstup)
mammals$county <- as.factor(mammals$county)

#calculate richness by county and make histogram
richness <- rowSums(mammals[,3:80])
hist(richness)

# plot richness as function of area (regular and on log scales)
plot(covariates$area,richness)
plot(log(covariates$area),log(richness))

# fit linear model and get summary (incl. R^2, coef. of determination)
model <- lm(log(richness)~log(covariates$area))
summary(model)
summary(model)$r.squared

# identify counties that belong to particular physiographic region
idx <- which(covariates$region=="LowerCoastal")

# plot richness vs log(area) for physiographic region
plot(log(covariates$area)[idx],log(richness)[idx])

# fit model as before
model2 <- lm(log(richness)[idx]~log(covariates$area)[idx])
summary(model2)

# function to combine areas of several counties
combineAreas <- function(df,counties){
  idx <- which(df$county %in% counties)
  area <- sum(df$area[idx])
  return(area)
}

# test function
counties <- c("Appling","Clarke")
combineAreas(covariates,counties)

# function to calculate richness in combined counties
combineRichness <- function(df,counties){
  idx <- which(df$county %in% counties)
  counts <- colSums(df[idx,3:80])
  richness <- length(which(counts>0))
  return(richness)
}

# test function
combineRichness(mammals,counties)


# make a random set of counties 
sampleCounties <- sample(covariates$county,20)

results <- NULL

for (i in 1:20){
  subsampleCounties <- sampleCounties[1:i]
  results <- rbind(results,c(combineAreas(covariates,subsampleCounties),combineRichness(mammals,subsampleCounties)))
}

# conver results matrix into a dataframe
results <- as.data.frame(results)
names(results) <- c("area","richness")

# plot as before
plot(results$area,results$richness)
plot(log(results$area),log(results$richness))

# fit model as before
model3 <- lm(log(results$richness)~log(results$area))
summary(model3)




